<?php

/**
 * @file
 * SimplerAds Filters.
 */

/**
 * Implements hook_filter_info().
 */
function simplerads_filter_info() {
  $filters = [];
  $filters['simplerads'] = [
    'title' => t('SimplerAds Filter'),
    'description' => t('Substitutes [ads:TID limit:N] with Ad block.'),
    'process callback' => '_simplerads_filter_process',
    'tips callback' => '_simplerads_filter_tips',
    'weight' => -1,
  ];
  return $filters;
}

/**
 * Filter Process callback.
 */
function _simplerads_filter_process($text, $filter, $format, $langcode, $cache, $cache_id) {
  if (preg_match_all('/\[ads(\:(.+))?( .+)?\]/isU', $text, $matches_code)) {
    foreach ($matches_code[0] as $ci => $code) {
      $ad = [
        'tid' => $matches_code[2][$ci],
        'ads_page' => '',
        'width' => '',
        'height' => '',
      ];
      if ($matches_code[3][$ci] && preg_match_all('/\s+([a-zA-Z_]+)\:(\s+)?([0-9a-zA-Z\/]+)/i', $matches_code[3][$ci], $matches_attributes)) {
        foreach ($matches_attributes[0] as $key => $attribute) {
          $ad[$matches_attributes[1][$key]] = $matches_attributes[3][$key];
        }
      }
      // Injecting an Ad into content.
      $content_ad = theme('simplerads_block', [
        'tid' => $ad['tid'],
        'prefix' => 'content-' . $ci,
        'ads_limit' => $ad['limit'],
        'ads_page' => $ad['ads_page'],
        'ads_width' => $ad['width'],
        'ads_height' => $ad['height'],
      ]);
      $pattern = str_replace(['[', ']'], ['\[', '\]'], $matches_code[0][$ci]);
      $text = preg_replace('/' . $pattern . '/is', $content_ad, $text);
    }
  }

  return $text;
}

/**
 * Filter Tips callback.
 */
function _simplerads_filter_tips($filter, $format, $long = FALSE) {
  return t('You may insert Ads with [ads:term_id limit:N] where term_id - Ad Group and N - number of Ads to display');
}

/**
 * Implements hook_wysiwyg_plugin().
 */
function simplerads_wysiwyg_plugin($editor, $version) {

  _simplerads_filter_add_settings('wysiwyg_' . $editor);

  $plugins = [];

  switch ($editor) {
    case 'tinymce':
      $plugins['simplerads'] = [
        'path' => drupal_get_path('module', 'simplerads') . '/editors/tinymce',
        'filename' => 'editor_plugin.js',
        'buttons' => ['simplerads' => t('Inject ads into content')],
        'load' => TRUE,
      ];
      break;
    case 'ckeditor':
      $plugins['simplerads'] = [
        'path' => drupal_get_path('module', 'simplerads') . '/editors/ckeditor/',
        'buttons' => ['simplerads' => t('Inject ads into content')],
        'load' => TRUE,
      ];
      break;
  }

  return $plugins;
}

/**
 * WYSIWYG Popup page.
 */
function _simplerads_filter_dashboard_page($editor) {

  module_invoke('admin_menu', 'suppress');

  switch ($editor) {
    case 'wysiwyg_tinymce':
      drupal_add_js(wysiwyg_get_path('tinymce') . '/jscripts/tiny_mce/tiny_mce_popup.js');
      drupal_add_js(drupal_get_path('module', 'simplerads') . '/editors/tinymce/simplerads_filter.js');
      break;

    case 'ckeditor':
    case 'wysiwyg_ckeditor':
      drupal_add_js(drupal_get_path('module', 'simplerads') . '/editors/ckeditor/simplerads_filter_dialog.js');
      break;
  }

  $form = render(drupal_get_form('_simplerads_filter_form'));

  print theme('simplerads_filter_dashboard', ['form' => $form]);
  exit();
}

/**
 * Return the theme name to be used when showing linkit dashboard
 */
function _simplerads_filter_dashboard_theme() {
  return variable_get('admin_theme', 'seven');
}

/**
 * Template preprocess function for simplerads_filter_dashboard().
 */
function template_preprocess_simplerads_filter_dashboard(&$vars) {
  $vars['head_title'] = t('SimplerAds Filter');
  $vars['head'] = drupal_get_html_head();
  $vars['help'] = theme('help');
  $vars['language'] = $GLOBALS['language'];
  $vars['language']->dir = $GLOBALS['language']->direction ? 'rtl' : 'ltr';
  $vars['messages'] = isset($vars['show_messages']) ? theme('status_messages') : '';
  $vars['css'] = drupal_add_css();
  $vars['styles'] = drupal_get_css();
  $vars['scripts'] = drupal_get_js();
}

/**
 * SimplerAds Filter form to insert Ads.
 */
function _simplerads_filter_form() {

  $form['simplerads_filter'] = [
    '#type' => 'fieldset',
    '#title' => t('Insert Ad Block'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#attributes' => ['class' => ['clearfix']],
  ];

  $ad_group_vid = db_select('taxonomy_vocabulary', 'tv')
    ->fields('tv', ['vid'])
    ->condition('machine_name', 'simplerad_groups')
    ->execute()
    ->fetchField();
  $results = db_select('taxonomy_term_data', 'td')->fields('td', [
    'tid',
    'name',
  ])->condition('vid', $ad_group_vid)->execute();
  $terms = [];
  foreach ($results as $record) {
    $terms[$record->tid] = check_plain($record->name);
  }

  $options = [];
  for ($i = 1; $i < 11; $i++) {
    $options[$i] = $i;
  }

  $form['simplerads_filter']['tid'] = [
    '#type' => 'select',
    '#title' => t('Ad Group'),
    '#options' => $terms,
  ];

  $form['simplerads_filter']['num'] = [
    '#type' => 'select',
    '#title' => t('Number of Ads to Display'),
    '#options' => $options,
  ];

  $form['insert'] = [
    '#type' => 'button',
    '#value' => t('Insert'),
    '#attributes' => ['style' => 'margin-right: 5px;'],
  ];

  $form['cancel'] = [
    '#type' => 'button',
    '#value' => t('Cancel'),
  ];

  return $form;
}

/**
 * Implements hook_element_info_alter().
 */
function simplerads_element_info_alter(&$types) {
  if (isset($types['text_format']['#pre_render']) && is_array($types['text_format']['#pre_render'])) {
    if (in_array('ckeditor_pre_render_text_format', $types['text_format']['#pre_render'])) {
      _simplerads_filter_add_settings('ckeditor');
    }
  }
}

/**
 * SimplerAds Filter global JS variables.
 */
function _simplerads_filter_add_settings($editor) {
  static $editor_settings_added = [];
  static $global_settings_added = FALSE;

  if (!isset($editor_settings_added[$editor])) {
    $editor_settings_added[$editor] = TRUE;
    $settings = [
      'simplerads' => ['url' => [$editor => url('simplerads/dashboard/' . $editor)]],
    ];
    drupal_add_js($settings, 'setting');
  }

  if (!$global_settings_added) {
    $global_settings_added = TRUE;
    $settings = [
      'simplerads' => [
        'modulepath' => drupal_get_path('module', 'simplerads'),
      ],
    ];
    drupal_add_js($settings, 'setting');
  }
}