<?php

/**
 * @file
 * SimplerAds Integration with other contributed modules.
 */

/**
 * Implements hook_views_api().
 */
function simplerads_views_api() {
  return [
    'api' => 3,
    'path' => drupal_get_path('module', 'simplerads') . '/includes',
    'template path' => drupal_get_path('module', 'simplerads') . '/templates',
  ];
}

/**
 * Implements hook_views_plugins().
 */
function simplerads_views_plugins() {
  // Declare the views_json style plugin.
  return [
    'style' => [
      'simplerads' => [
        'title' => t('SimplerAds'),
        'help' => t('Displays ads in block'),
        'handler' => 'views_simplerads_plugin',
        'theme' => 'views_simplerads',
        'theme path' => drupal_get_path('module', 'simplerads') . '/templates',
        'theme file' => 'views-simplerads.tpl.php',
        'uses row plugin' => FALSE,
        'uses fields' => TRUE,
        'uses options' => TRUE,
        'type' => 'normal',
      ],
    ],
  ];
}

/**
 * Implements hook_views_data().
 */
function simplerads_views_data() {
  // Describe simplerads_clicks table.
  $data['simplerads_clicks']['table']['group'] = t('SimplerAds clicks');

  $data['simplerads_clicks']['table']['base'] = [
    'field' => 'nid',
    'title' => t('SimplerAds clicks'),
    'help' => t("This table contains ad clicks statistics."),
    'weight' => 0,
  ];

  $data['simplerads_clicks']['table']['join'] = [
    'node' => [
      'left_field' => 'nid',
      'field' => 'nid',
    ],
  ];

  $data['simplerads_clicks']['nid'] = [
    'title' => t('Advertisement id'),
    'help' => t('References to SimplerAd node.'),
    'relationship' => [
      'base' => 'node',
      'field' => 'nid',
      'handler' => 'views_handler_relationship',
      'label' => t('SimplerAd node'),
    ],
  ];

  $data['simplerads_clicks']['ip_address'] = [
    'title' => t('Ip Address'),
    'help' => t('Ip address of the visitor.'),
    'field' => [
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ],
    'sort' => [
      'handler' => 'views_handler_sort',
    ],
    'filter' => [
      'handler' => 'views_handler_filter_string',
    ],
    'argument' => [
      'handler' => 'views_handler_argument_string',
    ],
  ];

  $data['simplerads_clicks']['timestamp'] = [
    'title' => t('Timestamp'),
    'help' => t('Timestamp when someone clicked on the ad.'),
    'field' => [
      'handler' => 'views_handler_field_date',
      'click sortable' => TRUE,
    ],
    'sort' => [
      'handler' => 'views_handler_sort_date',
    ],
    'filter' => [
      'handler' => 'views_handler_filter_date',
    ],
  ];

  // Describe simplerads_impressions table.
  $data['simplerads_impressions']['table']['group'] = t('SimplerAds impressions');
  $data['simplerads_impressions']['table']['base'] = [
    'field' => 'nid',
    'title' => t('SimplerAds impressions'),
    'help' => t("This table contains ad impressions statistics."),
    'weight' => 0,
  ];

  $data['simplerads_impressions']['table']['join'] = [
    'node' => [
      'left_field' => 'nid',
      'field' => 'nid',
    ],
  ];

  $data['simplerads_impressions']['nid'] = [
    'title' => t('Advertisement id'),
    'help' => t('References to SimplerAd node.'),
    'relationship' => [
      'base' => 'node',
      'field' => 'nid',
      'handler' => 'views_handler_relationship',
      'label' => t('SimplerAd node'),
    ],
  ];

  $data['simplerads_impressions']['ip_address'] = [
    'title' => t('Ip Address'),
    'help' => t('Ip address of the visitor.'),
    'field' => [
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ],
    'sort' => [
      'handler' => 'views_handler_sort',
    ],
    'filter' => [
      'handler' => 'views_handler_filter_string',
    ],
    'argument' => [
      'handler' => 'views_handler_argument_string',
    ],
  ];

  $data['simplerads_impressions']['timestamp'] = [
    'title' => t('Timestamp'),
    'help' => t('Timestamp when when the ad was displayed.'),
    'field' => [
      'handler' => 'views_handler_field_date',
      'click sortable' => TRUE,
    ],
    'sort' => [
      'handler' => 'views_handler_sort_date',
    ],
    'filter' => [
      'handler' => 'views_handler_filter_date',
    ],
  ];

  return $data;
}

/**
 * Implements hook_views_default_views().
 */
function simplerads_views_default_views() {
  $view = new view;
  $view->name = 'simplerads_block_example';
  $view->description = '';
  $view->tag = 'default';
  $view->base_table = 'node';
  $view->human_name = 'SimplerAds Block Example';
  $view->core = 7;
  $view->api_version = '3.0';
  $view->disabled = TRUE;

  /* Display: Master */
  $handler = $view->new_display('default', 'Master', 'default');
  $handler->display->display_options['title'] = 'SimplerAds Block Example';
  $handler->display->display_options['access']['type'] = 'perm';
  $handler->display->display_options['cache']['type'] = 'none';
  $handler->display->display_options['query']['type'] = 'views_query';
  $handler->display->display_options['query']['options']['query_comment'] = FALSE;
  $handler->display->display_options['exposed_form']['type'] = 'basic';
  $handler->display->display_options['pager']['type'] = 'some';
  $handler->display->display_options['pager']['options']['items_per_page'] = '5';
  $handler->display->display_options['style_plugin'] = 'simplerads';
  $handler->display->display_options['style_options']['ads_rotation_type'] = '1';
  $handler->display->display_options['style_options']['ads_rotation_delay'] = '5';
  /* Field: Content: Ad Group */
  $handler->display->display_options['fields']['field_simplerad_category']['id'] = 'field_simplerad_category';
  $handler->display->display_options['fields']['field_simplerad_category']['table'] = 'field_data_field_simplerad_category';
  $handler->display->display_options['fields']['field_simplerad_category']['field'] = 'field_simplerad_category';
  $handler->display->display_options['fields']['field_simplerad_category']['label'] = '';
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['external'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['alter']['html'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['element_label_colon'] = FALSE;
  $handler->display->display_options['fields']['field_simplerad_category']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['field_simplerad_category']['hide_empty'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['empty_zero'] = 0;
  $handler->display->display_options['fields']['field_simplerad_category']['hide_alter_empty'] = 1;
  $handler->display->display_options['fields']['field_simplerad_category']['field_api_classes'] = 0;
  /* Sort criterion: Global: Random */
  $handler->display->display_options['sorts']['random']['id'] = 'random';
  $handler->display->display_options['sorts']['random']['table'] = 'views';
  $handler->display->display_options['sorts']['random']['field'] = 'random';
  /* Filter criterion: Content: Published */
  $handler->display->display_options['filters']['status']['id'] = 'status';
  $handler->display->display_options['filters']['status']['table'] = 'node';
  $handler->display->display_options['filters']['status']['field'] = 'status';
  $handler->display->display_options['filters']['status']['value'] = 1;
  $handler->display->display_options['filters']['status']['group'] = 0;
  $handler->display->display_options['filters']['status']['expose']['operator'] = FALSE;
  /* Filter criterion: Content: Type */
  $handler->display->display_options['filters']['type']['id'] = 'type';
  $handler->display->display_options['filters']['type']['table'] = 'node';
  $handler->display->display_options['filters']['type']['field'] = 'type';
  $handler->display->display_options['filters']['type']['value'] = [
    'simplerads' => 'simplerads',
  ];
  /* Filter criterion: Content: Status (field_simplerad_status) */
  $handler->display->display_options['filters']['field_simplerad_status_value']['id'] = 'field_simplerad_status_value';
  $handler->display->display_options['filters']['field_simplerad_status_value']['table'] = 'field_data_field_simplerad_status';
  $handler->display->display_options['filters']['field_simplerad_status_value']['field'] = 'field_simplerad_status_value';
  $handler->display->display_options['filters']['field_simplerad_status_value']['value'] = [
    1 => '1',
  ];

  /* Display: Block */
  $handler = $view->new_display('block', 'Block', 'block');
  $handler->display->display_options['block_description'] = 'Views: SimplerAds Block Example';

  $views[$view->name] = $view;
  return $views;
}
