<?php

/**
 * @file
 * SimplerAds Theme.
 */

/**
 * Implements hook_theme().
 */
function simplerads_theme($existing, $type, $theme, $path) {
  return [
    'simplerads_block' => [
      'variables' => [
        'tid' => NULL,
        'prefix' => NULL,
        'ads_limit' => NULL,
        'ads_page' => NULL,
        'ads_width' => NULL,
        'ads_height' => NULL,
      ],
      'path' => $path . '/templates',
      'template' => 'simplerads_block',
      'preprocess functions' => [
        'simplerads_preprocess_simplerads_block',
      ],
    ],
    'simplerads_ajax_call' => [
      'variables' => [
        'content' => NULL,
        'total_ads' => NULL,
        'tid' => NULL,
        'settings' => NULL,
      ],
      'path' => $path . '/templates',
      'template' => 'simplerads_ajax_call',
    ],
    'simplerads_img_element' => [
      'variables' => ['ad' => NULL, 'settings' => NULL, 'css_class' => NULL],
      'path' => $path . '/templates',
      'template' => 'simplerads_img_element',
      'preprocess functions' => [
        'simplerads_preprocess_simplerads_img_element',
      ],
    ],
    'simplerads_text_element' => [
      'variables' => ['ad' => NULL, 'settings' => NULL, 'css_class' => NULL],
      'path' => $path . '/templates',
      'template' => 'simplerads_text_element',
      'preprocess functions' => [
        'simplerads_preprocess_simplerads_text_element',
      ],
    ],
    'simplerads_filter_dashboard' => [
      'variables' => ['form' => NULL],
      'path' => $path . '/templates',
      'template' => 'simplerads_filter_dashboard',
    ],
  ];
}

/**
 * Preprocess for simplerads_block.tpl.php
 */
function simplerads_preprocess_simplerads_block(&$vars) {
  global $user;
  $ads = [];

  $vars = _simplerads_theme_attributes_init($vars);

  $tid = $vars['tid'];
  $limit = $vars['ads_limit'];

  if (is_numeric($tid)) {
    $ads = _simplerads_load_ads($tid, $limit);
  }
  $vars['ads'] = $ads;
  $vars['user_id'] = $user->uid;
}

/**
 * Preprocess for simplerads_img_element.tpl.php
 */
function simplerads_preprocess_simplerads_img_element(&$vars) {
  $link_attributes = [];
  $image_attributes = [];
  $vars = _simplerads_theme_attributes_init($vars);
  _simplerads_increase_impression($vars['ad']['node']);
  // Image attributes
  $image_attributes['path'] = $vars['ad']['image_uri'];
  $image_attributes['alt'] = check_plain($vars['ad']['alt']);
  if (isset($vars['settings']['ads_width']) && is_numeric($vars['settings']['ads_width'])) {
    $image_attributes['width'] = check_plain($vars['settings']['ads_width']);
  }
  if (isset($vars['settings']['ads_height']) && is_numeric($vars['settings']['ads_height'])) {
    $image_attributes['height'] = check_plain($vars['settings']['ads_height']);
  }

  // Link attributes
  $link_attributes['html'] = TRUE;
  if ($vars['ad']['target'] && !user_access('administer nodes')) {
    $link_attributes['attributes']['target'] = '_blank';
  }

  $vars['link_attributes'] = $link_attributes;
  $vars['image_attributes'] = $image_attributes;
}

/**
 * Preprocess for simplerads_text_element.tpl.php
 */
function simplerads_preprocess_simplerads_text_element(&$vars) {
  $link_attributes = [];
  $vars = _simplerads_theme_attributes_init($vars);
  _simplerads_increase_impression($vars['ad']['node']);
  // Link attributes
  $link_attributes['html'] = TRUE;
  if ($vars['ad']['target'] && !user_access('administer nodes')) {
    $link_attributes['attributes']['target'] = '_blank';
  }
  $text_ad = "";
  if (!empty($vars['ad']['destination_url']) && $vars['ad']['text_format'] == 'plain_text') {
    $text_ad = l($vars['ad']['text'], $vars['ad']['url'], $link_attributes);
  }
  else {
    $text_ad = $vars['ad']['text'];
  }

  $vars['text_ad'] = $text_ad;
}

/**
 * Preprocess for SimplerAds Views template.
 * views-simplerads.tpl.php
 */
function template_preprocess_views_simplerads(&$vars) {
  $tid = 0;
  $ads = [];
  $ad_settings = [];
  $block_settings = [];
  $view = $vars['view'];
  $rows = $vars['rows'];
  $options = $vars['options'];
  $default_limit = variable_get('simplerads_default_ads_limit', 10);
  $limit = property_exists($view->query, 'limit') ? check_plain($view->query->limit) : $default_limit;

  if (count($rows) > 0) {
    foreach ($rows as $i => $data) {
      if (isset($data->field_field_simplerad_category[0])) {
        $tid = $data->field_field_simplerad_category[0]['raw']['tid'];
        $node = $data->_field_data['nid']['entity'];
        $ads[] = _simplerads_ads_data($node);
      }
    }
  };

  $prefix = 'views-' . $view->name . '-' . $tid . '-' . rand(1, 1000);

  $ad_settings['ads_height'] = $options['ads_height'];
  $ad_settings['ads_width'] = $options['ads_width'];

  $block_settings['ads_rotation_type'] = $options['ads_rotation_type'];
  $block_settings['ads_rotation_delay'] = $options['ads_rotation_delay'];
  $block_settings['block_delta'] = $prefix;

  $vars['tid'] = $tid;
  $vars['prefix'] = $prefix;
  $vars['ads_list'] = _simplerads_render_ajax_template($ads, $tid, $limit, $ad_settings, $block_settings);

}
