<?php

/**
 * @file
 * SimplerAds Campaigns menu callbacks.
 */

/**
 * Menu callback.
 *
 * Redirect to SimplerAd Campiagn creation form.
 */
function _simplerads_campaign_new() {
  drupal_goto('node/add/simplerads-campaign', [
    'query' => [
      'destination' => 'admin/content/simplerads_campaigns',
    ],
  ]);
}

/**
 * Menu callback.
 *
 * Campaigns listing page.
 */
function _simplerads_campaign_listing() {
  drupal_set_title(t('Advertisement Campaigns'));

  $header = [
    ['data' => ''],
    ['data' => t('Campaign')],
    ['data' => t('Start Date')],
    ['data' => t('Impressions')],
    ['data' => t('Clicks')],
    ['data' => t('Days')],
    ['data' => t('Active')],
    ['data' => t('Operations')],
  ];

  $query = db_select('node', 'n')->extend('PagerDefault')->limit(15);
  $query->fields('n', ['nid']);
  $query->condition('n.type', 'simplerads_campaign');
  $query->orderBy('n.changed', 'DESC');
  $results = $query->execute();

  $rows = [];
  foreach ($results as $i => $record) {

    $query = db_select('node', 'n');
    $query->join('field_data_field_simpleradcmp_list', 'l', 'l.entity_id = n.nid AND l.revision_id = n.vid');
    $query->fields('n', ['nid']);
    $query->fields('l', ['field_simpleradcmp_list_value']);
    $query->condition('n.type', 'simplerads');
    $query->condition('l.field_simpleradcmp_list_value', $record->nid);
    $query->addTag('node_access');
    $count = $query->countQuery()->execute()->fetchField();

    $node = node_load($record->nid);
    if ($node) {
      $impressions = '-';
      if (isset($node->field_simpleradcmp_impression[$node->language]) && $node->field_simpleradcmp_impression[$node->language][0]['value'] == 1) {
        if (isset($node->field_simpleradcmp_impressions[$node->language]) && !empty($node->field_simpleradcmp_impressions[$node->language][0]['safe_value'])) {
          $impressions = $node->field_simpleradcmp_impressions[$node->language][0]['safe_value'];
        }
      }
      $clicks = '-';
      if (isset($node->field_simpleradcmp_click[$node->language]) && $node->field_simpleradcmp_click[$node->language][0]['value'] == 1) {
        if (isset($node->field_simpleradcmp_clicks[$node->language]) && !empty($node->field_simpleradcmp_clicks[$node->language][0]['safe_value'])) {
          $clicks = $node->field_simpleradcmp_clicks[$node->language][0]['safe_value'];
        }
      }
      
      $days = '-';
      if (isset($node->field_simpleradcmp_day[$node->language]) && $node->field_simpleradcmp_day[$node->language][0]['value'] == 1) {
        if (isset($node->field_simpleradcmp_days[$node->language]) && !empty($node->field_simpleradcmp_days[$node->language][0]['safe_value'])) {
          $days = $node->field_simpleradcmp_days[$node->language][0]['safe_value'];
        }
      }
      
      $start_date = '-';
      if (isset($node->field_simpleradcmp_start[$node->language]) && !empty($node->field_simpleradcmp_start[$node->language][0]['value'])) {
        if (isset($node->field_simpleradcmp_start[$node->language]) && !empty($node->field_simpleradcmp_start[$node->language][0]['safe_value'])) {
          $start_date = $node->field_simpleradcmp_start[$node->language][0]['safe_value'];
        }
      }
      
      $is_active = t('No');
      if ($node->status == 1) {
        $is_active = t('Yes');
      }
      
      $rows[] = [
        ['data' => ($i + 1)],
        ['data' => l($node->title, 'admin/content/simplerads_campaigns/' . $node->nid) . ' (' . $count . ')'],
        ['data' => $start_date],
        ['data' => $impressions],
        ['data' => $clicks],
        ['data' => $days],
        ['data' => $is_active],
        [
          'data' => l(t('View'), 'admin/content/simplerads_campaigns/' . $node->nid, ['query' => ['destination' => 'admin/content/simplerads_campaigns']]) . '&nbsp;&nbsp; ' .
            l(t('Edit'), 'node/' . $node->nid . '/edit', ['query' => ['destination' => 'admin/content/simplerads_campaigns']]) . '&nbsp;&nbsp; ' .
            l(t('Delete'), 'node/' . $node->nid . '/delete', ['query' => ['destination' => 'admin/content/simplerads_campaigns']]) . '&nbsp;&nbsp; ',
        ],
      ];
    }
  }
  
  return theme('table', [
      'header' => $header,
      'rows' => $rows,
      'empty' => t('There are no Campaigns'),
    ]) . theme('pager');
}

/**
 * Menu callback.
 * Campaign details.
 */
function _simplerads_campaign_details($nid) {
  if (is_numeric($nid)) {
    $campaign_information = [];
    $campaign = node_load($nid);
    drupal_set_title(t('Advertisement Campaign'));

    $header = [
      ['data' => ''],
      ['data' => t('Advertisement')],
      ['data' => t('Impressions left')],
      ['data' => t('Clicks left')],
      ['data' => t('Days left')],
      ['data' => t('Ad Status')],
      ['data' => t('Operations')],
    ];

    $campaign_information[] = '<div><h2>' . $campaign->title . ' - ' . l(t('Edit'), 'node/' . $campaign->nid . '/edit', ['query' => ['destination' => 'admin/content/simplerads_campaigns']]) . '</h2></div>';
    $campaign_information[] = '<div><em>' . t('The ad remains in Active state until it reaches the number of impressions, clicks or the number of days, whichever comes first.') . '</em></div>';
    $campaign_information[] = '<hr>';

    if (isset($campaign->field_simpleradcmp_start[$campaign->language]) && !empty($campaign->field_simpleradcmp_start[$campaign->language][0]['safe_value'])) {
      $campaign_information[] = t('Started on !date', ['!date' => '<strong>' . $campaign->field_simpleradcmp_start[$campaign->language][0]['safe_value'] . '</strong>']);
    }

    if (isset($campaign->field_simpleradcmp_impression[$campaign->language]) && 
      $campaign->field_simpleradcmp_impression[$campaign->language][0]['value'] == 1
    ) {
      if (isset($campaign->field_simpleradcmp_impressions[$campaign->language]) && 
        !empty($campaign->field_simpleradcmp_impressions[$campaign->language][0]['safe_value'])
      ) {
        $campaign_information[] = '<div>' . t('Impressions limit: !num', ['!num' => '<strong>' . $campaign->field_simpleradcmp_impressions[$campaign->language][0]['safe_value'] . '</strong>']) . '</div>';
      }
    }
    if (isset($campaign->field_simpleradcmp_click[$campaign->language]) && $campaign->field_simpleradcmp_click[$campaign->language][0]['value'] == 1) {
      if (isset($campaign->field_simpleradcmp_clicks[$campaign->language]) && !empty($campaign->field_simpleradcmp_clicks[$campaign->language][0]['safe_value'])) {
        $campaign_information[] = '<div>' . t('Clicks limit: !num', ['!num' => '<strong>' . $campaign->field_simpleradcmp_clicks[$campaign->language][0]['safe_value'] . '</strong>']) . '</div>';
      }
    }
    if (isset($campaign->field_simpleradcmp_day[$campaign->language]) && $campaign->field_simpleradcmp_day[$campaign->language][0]['value'] == 1) {
      if (isset($campaign->field_simpleradcmp_days[$campaign->language]) && !empty($campaign->field_simpleradcmp_days[$campaign->language][0]['safe_value'])) {
        $campaign_information[] = '<div>' . t('Days limit: !num', ['!num' => '<strong>' . $campaign->field_simpleradcmp_days[$campaign->language][0]['safe_value'] . '</strong>']) . '</div>';
      }
    }
    $campaign_information[] = '<br />';

    $query = db_select('node', 'n')->extend('PagerDefault')->limit(25);
    $query->join('field_data_field_simpleradcmp_list', 'l', 'l.entity_id = n.nid AND l.revision_id = n.vid');
    $query->fields('n', ['nid']);
    $query->fields('l', ['field_simpleradcmp_list_value']);
    $query->condition('n.type', 'simplerads');
    $query->condition('l.field_simpleradcmp_list_value', $campaign->nid);
    $query->addTag('node_access');
    $query->orderBy('n.changed', 'DESC');
    $results = $query->execute();

    $campaign_start_time = "";
    if (isset($campaign->field_simpleradcmp_start[$campaign->language]) && !empty($campaign->field_simpleradcmp_start[$campaign->language][0]['value'])) {
      $campaign_start_time = $campaign->field_simpleradcmp_start[$campaign->language][0]['value'];
    }
    $campaign_start_time = strtotime($campaign_start_time);

    $rows = [];
    foreach ($results as $i => $record) {

      $css_complete = "";
      $node = node_load($record->nid);
      if ($campaign) {
        $impressions = '-';
        if (isset($campaign->field_simpleradcmp_impression[$campaign->language]) && $campaign->field_simpleradcmp_impression[$campaign->language][0]['value'] == 1) {
          if (isset($campaign->field_simpleradcmp_impressions[$campaign->language]) && !empty($campaign->field_simpleradcmp_impressions[$campaign->language][0]['safe_value'])) {
            $count = _simplerads_campaigns_count_ad_impressions($campaign_start_time, $node->nid);
            $impressions = $campaign->field_simpleradcmp_impressions[$campaign->language][0]['safe_value'] - $count;
            if ($impressions <= 0) {
              $impressions = t('Complete');
              $css_complete = 'complete';
            }
          }
        }
        
        $clicks = '-';
        if (isset($campaign->field_simpleradcmp_click[$campaign->language]) && $campaign->field_simpleradcmp_click[$campaign->language][0]['value'] == 1) {
          if (isset($campaign->field_simpleradcmp_clicks[$campaign->language]) && !empty($campaign->field_simpleradcmp_clicks[$campaign->language][0]['safe_value'])) {
            $count = _simplerads_campaigns_count_ad_clicks($campaign_start_time, $node->nid);
            $clicks = $campaign->field_simpleradcmp_clicks[$campaign->language][0]['safe_value'] - $count;
            if ($clicks <= 0) {
              $clicks = t('Complete');
              $css_complete = 'complete';
            }
          }
        }
        
        $days = '-';
        if (isset($campaign->field_simpleradcmp_day[$campaign->language]) && $campaign->field_simpleradcmp_day[$campaign->language][0]['value'] == 1) {
          if (isset($campaign->field_simpleradcmp_days[$campaign->language]) && !empty($campaign->field_simpleradcmp_days[$campaign->language][0]['safe_value'])) {
            $days = $campaign->field_simpleradcmp_days[$campaign->language][0]['safe_value'];
            $campaign_end_time = REQUEST_TIME - (24 * 3600 * $days);
            $count = _simplerads_campains_date_diff($campaign_end_time, $campaign_start_time);
            if ($count <= 0) {
              $days = t('Complete');
              $css_complete = 'complete';
            }
            else {
              $days = $count;
            }
          }
        }
        
        $ad_status = t('Inactive');
        if (isset($node->field_simplerad_status[$node->language])) {
          if ($node->field_simplerad_status[$node->language][0]['value'] == 1) {
            $ad_status = t('Active');
          }
        }
        $rows[] = [
          'data' => [
            ($i + 1),
            l($node->title, 'admin/content/simplerads/' . $record->nid . '/stat'),
            $impressions,
            $clicks,
            $days,
            $ad_status,
            l(t('Edit'), 'node/' . $node->nid . '/edit', ['query' => ['destination' => 'admin/content/simplerads_campaigns/' . $nid]]),
          ],
          'class' => [$css_complete],
        ];
      }
    }
    
    return join("", $campaign_information)
      . theme('table', [
        'header' => $header,
        'rows' => $rows,
        'empty' => t('There are no ads in this campaign'),
      ]) . theme('pager');
  }
  else {
    return t('Invalid campaign id');
  }
}
