<?php

/**
 * @file
 * SimplerAds Statistics.
 */

/**
 * Callback for Ad Statistics page.
 */
function _simplerads_stat_tab($nid) {
  $result = " ";

  $stats_form = drupal_get_form('_simplerads_after_stats_form');
  $form_after_stats = drupal_render($stats_form);

  if (is_numeric($nid)) {
    $node = node_load($nid);
    if ($node) {
      $stats = _simplerads_get_statistics('simplerads_clicks', $nid);
      $stat_results = [];
      foreach ($stats as $key => $val) {
        $header[]['data'] = t($key);
        $stat_results[]['data'] = $val;
      }

      $clicks[] = $stat_results;

      $stats = _simplerads_get_statistics('simplerads_impressions', $nid);
      $stat_results = [];
      foreach ($stats as $key => $val) {
        $stat_results[]['data'] = $val;
      }

      $impressions[] = $stat_results;

      $term_name = "";
      $op_links = l(t('Edit'), 'node/' . $node->nid . '/edit', ['query' => ['destination' => 'admin/content/simplerads']]);
      if (isset($node->field_simplerad_category[$node->language]) && !empty($node->field_simplerad_category[$node->language][0]['tid'])) {
        $term = taxonomy_term_load($node->field_simplerad_category[$node->language][0]['tid']);
        $term_name = $term->name;
      }
      elseif (isset($node->field_simplerad_category[LANGUAGE_NONE]) && !empty($node->field_simplerad_category[LANGUAGE_NONE][0]['tid'])) {
        $term = taxonomy_term_load($node->field_simplerad_category[LANGUAGE_NONE][0]['tid']);
        $term_name = $term->name;
      }

      $result .= '<h1>' . t("@adgroup: @adtitle - !link", [
          '@adgroup' => $term_name,
          '@adtitle' => $node->title,
          '!link' => $op_links,
        ]) . '</h1>';
      $result .= '<span>' . _simplerads_stats_info($node, 'ad_status_detail') . '</span>';
      $result .= _simplerads_stats_info($node, 'detail');

      $result .= theme('table', [
        'header' => $header,
        'rows' => $clicks,
        'caption' => t('Ad Clicks / Unique Clicks'),
      ]);
      $result .= theme('table', [
        'header' => $header,
        'rows' => $impressions,
        'caption' => t('Ad Impressions / Unique Impressions'),
      ]);
      $result .= $form_after_stats;
    }
  }

  return $result;
}

/**
 * Empty Form placeholder. Allows other modules to alter the form and add
 * custom data below Ads Statistics tables.
 */
function _simplerads_after_stats_form() {
  $form = [];
  $form['markup_field'] = [
    '#markup' => '',
  ];
  return $form;
}

/**
 * Empty Form placeholder. Allows other modules to alter the form and add
 * custom data below Ads listing table.
 */
function _simplerads_after_listing_form() {
  $form = [];
  $form['markup_field'] = [
    '#markup' => '',
  ];
  return $form;
}

/**
 * Ad Groups Filter form.
 */
function _simplerads_group_filter_form() {
  $form = [];

  $terms = ['' => t('Show All')];
  $vid = db_select('taxonomy_vocabulary', 'tv')
    ->fields('tv', ['vid'])
    ->condition('tv.machine_name', 'simplerad_groups')
    ->execute()
    ->fetchField();
  $results = db_select('taxonomy_term_data', 'td')->fields('td', [
    'tid',
    'name',
  ])->condition('td.vid', $vid)->execute();
  foreach ($results as $record) {
    $terms[$record->tid] = $record->name;
  }

  $filter = ['adgroup' => '', 'adstatus' => '', 'adsperpage' => 35];
  $filters = variable_get('simplerads_filters', FALSE);
  if ($filters) {
    $filter = unserialize($filters);
  }

  $form['ad_filter'] = [
    '#type' => 'fieldset',
  ];

  $form['ad_filter']['css'] = [
    '#markup' => '<style>
      #-simplerads-group-filter-form .form-item { float: left; margin-right: 10px; }
      #-simplerads-group-filter-form .form-item .form-submit { margin-top: 20px; }
      </style>',
  ];

  $form['ad_filter']['adgroup'] = [
    '#type' => 'select',
    '#title' => t('Ad Group'),
    '#options' => $terms,
    '#default_value' => $filter['adgroup'],
  ];

  $statuses = [
    '' => t('All'),
    1 => t('Active'),
    0 => t('Inactive'),
  ];

  $form['ad_filter']['adstatus'] = [
    '#type' => 'select',
    '#title' => t('Status'),
    '#options' => $statuses,
    '#default_value' => $filter['adstatus'],
  ];

  $pages = [
    5 => 5,
    10 => 10,
    25 => 25,
    35 => 35,
    45 => 45,
    75 => 75,
    100 => 100,
  ];

  $form['ad_filter']['adsperpage'] = [
    '#type' => 'select',
    '#title' => t('Ads per page'),
    '#options' => $pages,
    '#default_value' => $filter['adsperpage'],
  ];

  $form['ad_filter']['filter'] = [
    '#type' => 'submit',
    '#value' => t('Filter'),
    '#prefix' => '<div class="form-item">',
    '#suffix' => '</div>',
  ];

  return $form;
}

/**
 * Form submit.
 */
function _simplerads_group_filter_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $filter = [
    'adgroup' => $values['adgroup'],
    'adstatus' => $values['adstatus'],
    'adsperpage' => $values['adsperpage'],
  ];
  variable_set('simplerads_filters', serialize($filter));
}

/**
 * Callback for Ads Listing page.
 */
function _simplerads_listing() {
  drupal_set_title(t('Advertisement Listing'));

  $filter_render = drupal_get_form('_simplerads_group_filter_form');
  $filter_form = drupal_render($filter_render);
  $listing_render = drupal_get_form('_simplerads_after_listing_form');
  $form_after_listing = drupal_render($listing_render);

  $header = [
    ['data' => t('Ad Title')],
    ['data' => t('Ad Group')],
    ['data' => t('Status')],
    ['data' => t('Active')],
    ['data' => t('Operations')],
  ];

  $filter = ['adgroup' => '', 'adstatus' => '', 'adsperpage' => 35];
  $filters = variable_get('simplerads_filters', FALSE);
  if ($filters) {
    $filter = unserialize($filters);
  }

  $results = _simplerads_ads_listing_query($filter);

  $rows = [];
  foreach ($results as $record) {

    $node = node_load($record->nid);
    if ($node) {

      $ad_title = _simplerads_stats_info($node, 'list');
      $ad_group = _simplerads_stats_info($node, 'ad_group');

      $rows[] = [
        ['data' => $ad_title],
        ['data' => $ad_group],
        ['data' => _simplerads_stats_info($node, 'ad_status')],
        ['data' => _simplerads_stats_info($node, 'ad_activity')],
        ['data' => _simplerads_stats_info($node, 'ad_operations')],
      ];
    }
  }
  return $filter_form . theme('table', [
      'header' => $header,
      'rows' => $rows,
      'empty' => t('There are no Ads'),
    ]) . theme('pager') . $form_after_listing;
}

/**
 * Helper function.
 * Display Ad statuses.
 */
function _simplerads_statuses($node) {
  $status = "";

  $start_time = "";
  $end_time = "";

  if (isset($node->field_simplerad_start_date[$node->language]) && !empty($node->field_simplerad_start_date[$node->language][0]['value'])) {
    $start_time = $node->field_simplerad_start_date[$node->language][0]['value'];
  }
  if (isset($node->field_simplerad_end_date[$node->language]) && !empty($node->field_simplerad_end_date[$node->language][0]['value'])) {
    $end_time = $node->field_simplerad_end_date[$node->language][0]['value'];
  }

  $ustart_time = strtotime(check_plain($start_time));
  $uend_time = strtotime(check_plain($end_time));
  $now = time();

  if ($node->status == 1) {
    $status .= t("Published");

    if ($start_time != '' && $end_time != '') {
      $status .= ", " . t("Active during (@startdate - @enddate)", [
          '@startdate' => $start_time,
          '@enddate' => $end_time,
        ]);
    }
    elseif ($start_time == '' && $end_time != '') {
      $status .= ", " . t("Expires on @datetime", ['@datetime' => $end_time]);
    }

  }
  else {
    $status .= t("Not Published");

    if ($start_time != '' && $end_time != '') {
      if ($uend_time <= $now) {
        $status = t("Expired on @datetime", ['@datetime' => $end_time]);
      }
      else {
        $status .= ", " . t("Start from (@startdate - @enddate)", [
            '@startdate' => $start_time,
            '@enddate' => $end_time,
          ]);
      }
    }
    elseif ($start_time == '' && $end_time != '') {
      if ($uend_time <= $now) {
        $status = t("Expired on @datetime", ['@datetime' => $end_time]);
      }
      else {
        $status .= ", " . t("Expires on @datetime", ['@datetime' => $end_time]);
      }
    }
  }
  return $status;
}

/**
 * Helper function.
 * Timestamp to days.
 */
function _simplerads_date_diff($node) {
  $start_time = "";
  $end_time = "";

  if (isset($node->field_simplerad_start_date[$node->language]) && !empty($node->field_simplerad_start_date[$node->language][0]['value'])) {
    $start_time = $node->field_simplerad_start_date[$node->language][0]['value'];
  }
  if (isset($node->field_simplerad_end_date[$node->language]) && !empty($node->field_simplerad_end_date[$node->language][0]['value'])) {
    $end_time = $node->field_simplerad_end_date[$node->language][0]['value'];
  }

  $ustart_time = strtotime($start_time);
  $uend_time = strtotime($end_time);
  $now = time();

  if ($ustart_time == '' && $uend_time != '') {
    return floor(($uend_time - $now) / 86400);
  }
  elseif ($ustart_time != '' && $uend_time != '') {
    return floor(($uend_time - $ustart_time) / 86400);
  }
  elseif ($ustart_time == '' && $uend_time == '') {
    return FALSE;
  }
  else {
    return 0;
  }
}

/**
 * Helper function.
 * Returns stats for given table name.
 */
function _simplerads_get_statistics($table, $nid) {
  $stats = [];

  if ($table == 'simplerads_clicks') {

    $stats['Yesterday'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= CURDATE()- 1
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= CURDATE() - 1
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['Last Week'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 WEEK)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 WEEK)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['Last Month'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['3 Months'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 3 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 3 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['6 Months'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 6 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 6 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['1 year'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 YEAR)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 YEAR)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['All Time'] = db_query("SELECT IFNULL(SUM(sc.clicks), 0) FROM {simplerads_stats} sc WHERE sc.nid = :nid", [':nid' => $nid])->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.clicks_unique), 0) FROM {simplerads_stats} sc WHERE sc.nid = :nid", [':nid' => $nid])->fetchField();

  }

  if ($table == 'simplerads_impressions') {

    $stats['Yesterday'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= CURDATE() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(CURDATE(), INTERVAL 1 DAY)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= CURDATE() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(CURDATE(), INTERVAL 1 DAY)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['Last Week'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 WEEK)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 WEEK)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['Last Month'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['3 Months'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 3 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 3 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['6 Months'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 6 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 6 MONTH)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['1 year'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 YEAR)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc
      WHERE STR_TO_DATE(sc.date, '%Y%m%d') <= NOW() AND STR_TO_DATE(sc.date, '%Y%m%d') >= SUBDATE(NOW(), INTERVAL 1 YEAR)
      AND sc.nid = :nid", [':nid' => $nid])
        ->fetchField();

    $stats['All Time'] = db_query("SELECT IFNULL(SUM(sc.impressions), 0) FROM {simplerads_stats} sc WHERE sc.nid = :nid", [':nid' => $nid])->fetchField() . '/' . db_query("SELECT IFNULL(SUM(sc.impressions_unique), 0) FROM {simplerads_stats} sc WHERE sc.nid = :nid", [':nid' => $nid])->fetchField();

  }

  t('Yesterday');
  t('Last Week');
  t('Last Month');
  t('3 Months');
  t('6 Months');
  t('1 year');
  t('All Time');

  return $stats;
}